# frozen_string_literal: true

module Jekyll
  module Filters
    module SocialNetwork
      # Takes a URL and returns a Hash of attributes, useful when you
      # want to generate social network buttons from an undetermined
      # list of URLs.
      #
      # @param [String]
      # @return [Hash]
      def social_network(url)
        return {} unless url.is_a? String

        require 'uri'

        uri  = URI url
        name = %r{/@\w+} =~ uri.query ? 'mastodon' : uri.host.split('.', 2).first

        { 'host' => uri.host, 'name' => name, 'url' => url }.to_liquid
      rescue URI::InvalidURIError => e
        Jekyll.logger.warn e.message

        {}.to_liquid
      end
    end
  end
end

Liquid::Template.register_filter(Jekyll::Filters::SocialNetwork)
